[cig-commits] r14667 - in short/3D/PyLith/branches/pylith-swig: . pylith/meshio unittests/pytests/meshio

brad at geodynamics.org brad at geodynamics.org
Fri Apr 10 21:34:02 PDT 2009


Author: brad
Date: 2009-04-10 21:34:01 -0700 (Fri, 10 Apr 2009)
New Revision: 14667

Modified:
   short/3D/PyLith/branches/pylith-swig/TODO
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilter.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManager.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilter.py
   short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestOutputManager.py
   short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/testmeshio.py
Log:
More work on Python unit tests for output.

Modified: short/3D/PyLith/branches/pylith-swig/TODO
===================================================================
--- short/3D/PyLith/branches/pylith-swig/TODO	2009-04-11 03:12:00 UTC (rev 14666)
+++ short/3D/PyLith/branches/pylith-swig/TODO	2009-04-11 04:34:01 UTC (rev 14667)
@@ -50,7 +50,8 @@
       Add cleanup() to non-components to deallocate local data structures.
 
     Create createModuleObj() methods to Python objects as standard way
-    of creating handle to C++ object.
+    of creating handle to C++ object (not necessary in abstract base
+    classes).
 
     Add check before calling newSection() when want to enforce at
     least 1 value.

Modified: short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilter.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilter.py	2009-04-11 03:12:00 UTC (rev 14666)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilter.py	2009-04-11 04:34:01 UTC (rev 14667)
@@ -35,6 +35,7 @@
     Constructor.
     """
     PetscComponent.__init__(self, name, facility="cellfilter")
+    self.filter = None
     return
 
 
@@ -56,7 +57,7 @@
 
 def output_cell_filter():
   """
-  Factory associated with CellFilter.
+  Factory associated with MeshCellFilter.
   """
   return CellFilter()
 

Modified: short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManager.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManager.py	2009-04-11 03:12:00 UTC (rev 14666)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManager.py	2009-04-11 04:34:01 UTC (rev 14667)
@@ -17,12 +17,12 @@
 ##
 ## Factory: output_manager
 
-from pyre.components.Component import Component
+from pylith.utils.PetscComponent import PetscComponent
 from meshio import MeshOutputManager as ModuleMeshObject
 from meshio import SubMeshOutputManager as ModuleSubMeshObject
 
 # OutputManager class
-class OutputManager(Component):
+class OutputManager(PetscComponent):
   """
   Python abstract base class for managing output of finite-element
   information.
@@ -35,6 +35,8 @@
   
   \b Facilities
   @li \b coordsys Coordinate system for output.
+  @li \b vertex_filter Filter for vertex data.
+  @li \b cell_filter Filter for cell data.
   """
 
   # INVENTORY //////////////////////////////////////////////////////////
@@ -54,13 +56,31 @@
                             validator=pyre.inventory.greaterEqual(0))
   skip.meta['tip'] = "Number of time steps to skip between output."
   
+  from spatialdata.geocoords.CSCart import CSCart
+  coordsys = pyre.inventory.facility("coordsys", family="coordsys",
+                                     factory=CSCart)
+  coordsys.meta['tip'] = "Coordinate system for output."
+  
+  from VertexFilter import VertexFilter
+  vertexFilter = pyre.inventory.facility("vertex_filter",
+                                         factory=VertexFilter,
+                                         family="output_vertex_filter")
+  vertexFilter.meta['tip'] = "Filter for vertex data."
+  
+  from CellFilter import CellFilter
+  cellFilter = pyre.inventory.facility("cell_filter",
+                                       factory=CellFilter,
+                                       family="output_cell_filter")
+  cellFilter.meta['tip'] = "Filter for cell data."
+  
+
   # PUBLIC METHODS /////////////////////////////////////////////////////
 
   def __init__(self, name="outputmanager"):
     """
     Constructor.
     """
-    Component.__init__(self, name, facility="outputmanager")
+    PetscComponent.__init__(self, name, facility="outputmanager")
     self._loggingPrefix = "OutM "
     self._stepCur = 0
     self._stepWrite = None
@@ -142,9 +162,8 @@
       nsteps = 1 + int(totalTime / self.dt)
 
     (mesh, label, labelId) = self.dataProvider.getDataMesh()
+    self._open(mesh, nsteps, label, labelId)
 
-    ModuleOutputManager.open(self, mesh, nsteps, label, labelId)
-
     self._logger.eventEnd(logEvent)    
     return
 
@@ -156,7 +175,7 @@
     logEvent = "%sclose" % self._loggingPrefix
     self._logger.eventBegin(logEvent)    
 
-    ModuleOutputManager.close(self)
+    self._close()
 
     self._logger.eventEnd(logEvent)    
     return
@@ -173,18 +192,18 @@
       t = 0.0
       self.open(totalTime=0.0, numTimeSteps=0)
       (mesh, label, labelId) = self.dataProvider.getDataMesh()
-      ModuleOutputManager.openTimeStep(self, t, mesh, label, labelId)
+      self._openTimeStep(t, mesh, label, labelId)
 
       for name in self.vertexInfoFields:
-        (field, fieldType) = self.dataProvider.getVertexField(name)
-        ModuleOutputManager.appendVertexField(self, t, field)
+        field = self.dataProvider.getVertexField(name)
+        self._appendVertexField(t, field)
 
       for name in self.cellInfoFields:
-        (field, fieldType) = self.dataProvider.getCellField(name)
-        ModuleOutputManager.appendCellField(self, t, field, label, labelId)
+        field = self.dataProvider.getCellField(name)
+        self._appendCellField(t, field, label, labelId)
 
-      ModuleOutputManager.closeTimeStep(self)
-      self.close()
+      self._closeTimeStep()
+      self._close()
 
     self._logger.eventEnd(logEvent)
     return
@@ -202,17 +221,17 @@
              len(self.cellDataFields) ) > 0:
 
       (mesh, label, labelId) = self.dataProvider.getDataMesh()
-      ModuleOutputManager.openTimeStep(self, t, mesh, label, labelId)
+      self._openTimeStep(t, mesh, label, labelId)
 
       for name in self.vertexDataFields:
-        (field, fieldType) = self.dataProvider.getVertexField(name, fields)
-        ModuleOutputManager.appendVertexField(self, t, field)
+        field = self.dataProvider.getVertexField(name, fields)
+        self._appendVertexField(t, field)
 
       for name in self.cellDataFields:
-        (field, fieldType) = self.dataProvider.getCellField(name, fields)
-        ModuleOutputManager.appendCellField(self, t, field)
+        field = self.dataProvider.getCellField(name, fields)
+        self._appendCellField(t, field, label, labelId)
 
-      ModuleOutputManager.closeTimeStep(self)
+      self._closeTimeStep(self)
 
     self._logger.eventEnd(logEvent)
     return
@@ -225,18 +244,9 @@
     Set members based using inventory.
     """
     PetscComponent._configure(self)
-    ModuleOutputManager.coordsys(self, self.coordsys)
     return
 
 
-  def _createModuleObj(self):
-    """
-    Create handle to C++ object.
-    """
-    ModuleOutputManager.__init__(self)
-    return
-
-
   def _checkWrite(self, t):
     """
     Check if we want to write data at time t.
@@ -336,6 +346,30 @@
     return
   
 
+  def _open(self):
+    raise NotImplementedError("Implement _open() in derived class.")
+
+
+  def _openTimeStep(self):
+    raise NotImplementedError("Implement _openTimeStep() in derived class.")
+
+
+  def _appendVertexField(self):
+    raise NotImplementedError("Implement _appendVertexField() in derived class.")
+
+
+  def _appendCellField(self):
+    raise NotImplementedError("Implement _appendCellField() in derived class.")
+
+
+  def _closeTimeStep(self):
+    raise NotImplementedError("Implement _closeTimeStep() in derived class.")
+
+
+  def _close(self):
+    raise NotImplementedError("Implement _close() in derived class.")
+
+
 # MeshOutputManager class
 class MeshOutputManager(OutputManager, ModuleMeshObject):
   """
@@ -347,8 +381,6 @@
   
   \b Facilities
   @li \b writer Writer for data.
-  @li \b vertex_filter Filter for vertex data.
-  @li \b cell_filter Filter for cell data.
 
   Factory: mesh_output_manager
   """
@@ -362,26 +394,14 @@
                                  family="mesh_data_writer")
   writer.meta['tip'] = "Writer for data."
 
-  from VertexFilter import MeshVertexFilter
-  vertexFilter = pyre.inventory.facility("vertex_filter",
-                                         factory=MeshVertexFilter,
-                                         family="mesh_output_vertex_filter")
-  vertexFilter.meta['tip'] = "Filter for vertex data."
-  
-  from CellFilter import MeshCellFilter
-  cellFilter = pyre.inventory.facility("cell_filter",
-                                       factory=MeshCellFilter,
-                                       family="mesh_output_cell_filter")
-  cellFilter.meta['tip'] = "Filter for cell data."
-  
 
   # PUBLIC METHODS /////////////////////////////////////////////////////
 
-  def __init__(self, name="outputmanager"):
+  def __init__(self, name="meshoutputmanager"):
     """
     Constructor.
     """
-    OutputManager.__init__(self, name, facility="meshoutputmanager")
+    OutputManager.__init__(self, name)
     self._createModuleObj()
     return
 
@@ -393,9 +413,12 @@
     Set members based using inventory.
     """
     OutputManager._configure(self)
-    ModuleMeshObject.writer(self.writer)
-    ModuleMeshObject.vertexFilter(self.vertexFilter)
-    ModuleMeshObject.cellFilter(self.cellFilter)
+    ModuleMeshObject.coordsys(self, self.inventory.coordsys)
+    ModuleMeshObject.writer(self, self.inventory.writer)
+    if None != self.vertexFilter.filter:
+      ModuleMeshObject.vertexFilter(self, self.inventory.vertexFilter)
+    if None != self.cellFilter.filter:
+      ModuleMeshObject.cellFilter(self, self.inventory.cellFilter)
     return
 
 
@@ -407,6 +430,59 @@
     return
 
 
+  def _open(self, mesh, nsteps, label, labelId):
+    """
+    Call C++ open();
+    """
+    if label != None and labelId != None:
+      ModuleMeshObject.open(self, mesh, nsteps, label, labelId)
+    else:
+      ModuleMeshObject.open(self, mesh, nsteps)
+    return
+
+
+  def _openTimeStep(self, t, mesh, label, labelId):
+    """
+    Call C++ openTimeStep();
+    """
+    if label != None and labelId != None:
+      ModuleMeshObject.openTimeStep(self, t, mesh, label, labelId)
+    else:
+      ModuleMeshObject.openTimeStep(self, t, mesh)
+    return
+
+
+  def _appendVertexField(self, t, field):
+    """
+    Call C++ appendVertexField();
+    """
+    ModuleMeshObject.appendVertexField(self, t, field)
+    return
+
+  def _appendCellField(self, t, field, label, labelId):
+    """
+    Call C++ appendCellField();
+    """
+    ModuleMeshObject.appendCellField(self, t, field)
+    return
+
+
+  def _closeTimeStep(self):
+    """
+    Call C++ closeTimeStep().
+    """
+    ModuleMeshObject.closeTimeStep(self)
+    return
+
+
+  def _close(self):
+    """
+    Call C++ close().
+    """
+    ModuleMeshObject.close(self)
+    return
+
+
 # SubMeshOutputManager class
 class SubMeshOutputManager(OutputManager, ModuleSubMeshObject):
   """
@@ -418,8 +494,6 @@
   
   \b Facilities
   @li \b writer Writer for data.
-  @li \b vertex_filter Filter for vertex data.
-  @li \b cell_filter Filter for cell data.
 
   Factory: mesh_output_manager
   """
@@ -433,26 +507,13 @@
                                  family="mesh_data_writer")
   writer.meta['tip'] = "Writer for data."
 
-  from VertexFilter import SubMeshVertexFilter
-  vertexFilter = pyre.inventory.facility("vertex_filter",
-                                         factory=SubMeshVertexFilter,
-                                         family="mesh_output_vertex_filter")
-  vertexFilter.meta['tip'] = "Filter for vertex data."
-  
-  from CellFilter import SubMeshCellFilter
-  cellFilter = pyre.inventory.facility("cell_filter",
-                                       factory=SubMeshCellFilter,
-                                       family="mesh_output_cell_filter")
-  cellFilter.meta['tip'] = "Filter for cell data."
-  
-
   # PUBLIC METHODS /////////////////////////////////////////////////////
 
-  def __init__(self, name="outputmanager"):
+  def __init__(self, name="submeshoutputmanager"):
     """
     Constructor.
     """
-    OutputManager.__init__(self, name, facility="meshoutputmanager")
+    OutputManager.__init__(self, name)
     self._createModuleObj()
     return
 
@@ -464,9 +525,12 @@
     Set members based using inventory.
     """
     OutputManager._configure(self)
-    ModuleSubMeshObject.writer(self.writer)
-    ModuleSubMeshObject.vertexFilter(self.vertexFilter)
-    ModuleSubMeshObject.cellFilter(self.cellFilter)
+    ModuleSubMeshObject.coordsys(self, self.inventory.coordsys)
+    ModuleSubMeshObject.writer(self, self.inventory.writer)
+    if None != self.vertexFilter.filter:
+      ModuleSubMeshObject.vertexFilter(self, self.inventory.vertexFilter)
+    if None != self.cellFilter.filter:
+      ModuleSubMeshObject.cellFilter(self, self.inventory.cellFilter)
     return
 
 
@@ -478,6 +542,59 @@
     return
 
 
+  def _open(self, mesh, nsteps, label, labelId):
+    """
+    Call C++ open();
+    """
+    if label != None and labelId != None:
+      ModuleSubMeshObject.open(self, mesh, nsteps, label, labelId)
+    else:
+      ModuleSubMeshObject.open(self, mesh, nsteps)
+    return
+
+
+  def _openTimeStep(self, t, mesh, label, labelId):
+    """
+    Call C++ openTimeStep();
+    """
+    if label != None and labelId != None:
+      ModuleSubMeshObject.openTimeStep(self, t, mesh, label, labelId)
+    else:
+      ModuleSubMeshObject.openTimeStep(self, t, mesh)
+    return
+
+
+  def _appendVertexField(self, t, field):
+    """
+    Call C++ appendVertexField();
+    """
+    ModuleSubMeshObject.appendVertexField(self, t, field)
+    return
+
+  def _appendCellField(self, t, field):
+    """
+    Call C++ appendCellField();
+    """
+    ModuleSubMeshObject.appendCellField(self, t, field)
+    return
+
+
+  def _closeTimeStep(self):
+    """
+    Call C++ closeTimeStep().
+    """
+    ModuleSubMeshObject.closeTimeStep(self)
+    return
+
+
+  def _close(self):
+    """
+    Call C++ close().
+    """
+    ModuleSubMeshObject.close(self)
+    return
+
+
 # FACTORIES ////////////////////////////////////////////////////////////
 
 def mesh_output_manager():

Modified: short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilter.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilter.py	2009-04-11 03:12:00 UTC (rev 14666)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilter.py	2009-04-11 04:34:01 UTC (rev 14667)
@@ -39,6 +39,7 @@
     Constructor.
     """
     PetscComponent.__init__(self, name, facility="vertexfilter")
+    self.filter = None
     return
 
 

Modified: short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestOutputManager.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/testmeshio.py	2009-04-11 03:12:00 UTC (rev 14666)
+++ short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/testmeshio.py	2009-04-11 04:34:01 UTC (rev 14667)
@@ -80,9 +80,12 @@
     from TestDataWriterVTK import TestSubMeshDataWriterVTK
     suite.addTest(unittest.makeSuite(TestSubMeshDataWriterVTK))
 
-    #from TestOutputManager import TestOutputManager
-    #suite.addTest(unittest.makeSuite(TestOutputManager))
+    from TestOutputManager import TestMeshOutputManager
+    suite.addTest(unittest.makeSuite(TestMeshOutputManager))
 
+    #from TestOutputManager import TestSubMeshOutputManager
+    #suite.addTest(unittest.makeSuite(TestSubMeshOutputManager))
+
     #from TestOutputSolnSubset import TestOutputSolnSubset
     #suite.addTest(unittest.makeSuite(TestOutputSolnSubset))
 



More information about the CIG-COMMITS mailing list
--- short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestOutputManager.py	2009-04-11 03:12:00 UTC (rev 14666)
+++ short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestOutputManager.py	2009-04-11 04:34:01 UTC (rev 14667)
@@ -16,7 +16,7 @@
 
 import unittest
 
-from pylith.meshio.OutputManager import OutputManager
+from pylith.meshio.OutputManager import MeshOutputManager
 
 # ----------------------------------------------------------------------
 class TestProvider(object):
@@ -34,21 +34,22 @@
            {'info': ["cell info"],
             'data': ["cell data"]}}
 
-    from pylith.meshio.MeshIOAscii import MeshIOAscii
-    iohandler = MeshIOAscii()
     filename = "data/twohex8.txt"
     
+    from pylith.meshio.MeshIOAscii import MeshIOAscii
+    iohandler = MeshIOAscii()
+    iohandler.inventory.filename = filename
+    from spatialdata.geocoords.CSCart import CSCart
+    iohandler.inventory.coordsys = CSCart()
+    iohandler._configure()
+
     from spatialdata.units.Nondimensional import Nondimensional
     normalizer = Nondimensional()
-    normalizer.initialize()
-
-    from spatialdata.geocoords.CSCart import CSCart
-    iohandler.filename = filename
-    iohandler.coordsys = CSCart()
+    normalizer._configure()
     mesh = iohandler.read(normalizer, debug=False, interpolate=False)
 
-    from pylith.topology.FieldsManager import FieldsManager
-    fields = FieldsManager(mesh)
+    from pylith.topology.Fields import MeshFields
+    fields = MeshFields(mesh)
     
     self.mesh = mesh
     self.fields = fields
@@ -66,23 +67,28 @@
     """
     Get vertex field.
     """
+    from pylith.field.field.FieldBase import SCALAR,VECTOR,OTHER
     if name == "vertex info":
-      fieldType = 0
+      fieldType = FieldBase.SCALAR
       fiberDim = 1
     elif name == "vertex data 1":
-      fieldType = 1
+      fieldType = FieldBase.VECTOR
       fiberDim = self.mesh.dimension()
     elif name == "vertex data 2":
-      fieldType = 3
+      fieldType = FieldBase.OTHER
       fiberDim = 5
     else:
       raise ValueError("Unknown field '%s'." % name)
 
-    self.fields.addReal(name)
+    self.fields.add(name, name)
+    field = self.fields.get(name)
+    field.newSection(field.VERTICES_FIELD, fiberDim)
+    field.allocate()
+    field.vectorFieldType(fieldType)
     self.fields.setFiberDimension(name, fiberDim)
     self.fields.allocate(name)
     field = self.fields.getReal(name)
-    return (field, fieldType)
+    return field
 
 
   def getCellField(self, name, fields=None):
@@ -90,31 +96,32 @@
     Get cell field.
     """
     if name == "cell info":
-      fieldType = 0
+      fieldType = FieldBase.SCALAR
       fiberDim = 1
     elif name == "cell data":
-      fieldType = 1
+      fieldType = FieldBase.VECTOR
       fiberDim = self.mesh.dimension()
     else:
       raise ValueError("Unknown field '%s'." % name)
 
-    self.fields.addReal(name)
-    self.fields.setFiberDimension(name, fiberDim, "cells")
-    self.fields.allocate(name)
-    field = self.fields.getReal(name)
-    return (field, fieldType)
+    self.fields.add(name, name)
+    field = self.fields.get(name)
+    field.newSection(field.CELLS_FIELD, fiberDim)
+    field.allocate()
+    field.vectorFieldType(fieldType)
+    return field
 
 
 # ----------------------------------------------------------------------
-class TestOutputManager(unittest.TestCase):
+class TestMeshOutputManager(unittest.TestCase):
   """
   Unit testing of Python OutputManager object.
   """
 
   def setUp(self):
     from spatialdata.units.Nondimensional import Nondimensional
     self.normalizer = Nondimensional()
-    self.normalizer.initialize()
+    self.normalizer._configure()
     return
   
 
@@ -122,31 +129,18 @@
     """
     Test constructor.
     """
-    output = OutputManager()
+    output = MeshOutputManager()
+    output.inventory.writer._configure()
     output._configure()
-    output.writer._configure()
     return
 
 
-  def test_sync(self):
-    """
-    Test _sync().
-    """
-    output = OutputManager()
-    output._configure()
-    output.writer._configure()
-    output.writer.initialize(self.normalizer)
-    output._sync()
-    self.assertNotEqual(None, output.cppHandle)
-    return
-  
-
   def test_preinitialize(self):
     """
     Test preinitialize().
     """
-    output = OutputManager()
     dataProvider = TestProvider()
+    output = MeshOutputManager()
     output.preinitialize(dataProvider)
     
     self.assertEqual(dataProvider, output.dataProvider)
@@ -157,8 +151,8 @@
     """
     Test verifyConfiguration().
     """
-    output = OutputManager()
     dataProvider = TestProvider()
+    output = MeshOutputManager()
     output.preinitialize(dataProvider)
 
     output.vertexInfoFields = ["vertex info"]
@@ -174,34 +168,34 @@
     Test initialize().
     """
     # No quadrature
-    output = OutputManager()
+    output = MeshOutputManager()
+    output.inventory.writer.inventory.filename = "test.vtk"
+    output.inventory.writer._configure()
     output._configure()
-    output.writer._configure()
-    output.writer.filename = "test.vtk"
     dataProvider = TestProvider()
     output.preinitialize(dataProvider)
     output.initialize(self.normalizer)
-    self.assertNotEqual(None, output.cppHandle)
 
     # With quadrature
     from pylith.feassemble.FIATSimplex import FIATSimplex
-    from pylith.feassemble.quadrature.Quadrature1D import Quadrature1D
+    from pylith.feassemble.Quadrature import MeshQuadrature
     cell = FIATSimplex()
-    cell.shape = "line"
-    cell.degree = 2
-    cell.order = 2
+    cell.inventory.shape = "line"
+    cell.inventory.degree = 2
+    cell.inventory.order = 2
+    cell._configure()
 
-    quadrature = Quadrature1D()
-    quadrature.cell = cell
+    quadrature = MeshQuadrature()
+    quadrature.inventory.cell = cell
+    quadrature._configure()
     
-    output = OutputManager()
+    output = MeshOutputManager()
+    output.inventory.writer.inventory.filename = "test.vtk"
+    output.inventory.writer._configure()
     output._configure()
-    output.writer._configure()
-    output.writer.filename = "test.vtk"
     dataProvider = TestProvider()
     output.preinitialize(dataProvider)
     output.initialize(self.normalizer, quadrature)
-    self.assertNotEqual(None, output.cppHandle)
     return
 
 
@@ -209,10 +203,10 @@
     """
     Test open() and close().
     """
-    output = OutputManager()
+    output = MeshOutputManager()
+    output.inventory.writer.inventory.filename = "output.vtk"
+    output.inventory.writer._configure()
     output._configure()
-    output.writer._configure()
-    output.writer.filename = "output.vtk"
     dataProvider = TestProvider()
     output.preinitialize(dataProvider)
     output.initialize(self.normalizer)
@@ -226,12 +220,12 @@
     """
     Test writeInfo().
     """
-    output = OutputManager()
+    output = MeshOutputManager()
+    output.inventory.writer.inventory.filename = "output.vtk"
+    output.inventory.writer._configure()
+    output.inventory.vertexInfoFields = ["vertex info"]
+    output.inventory.cellInfoFields = ["cell info"]
     output._configure()
-    output.writer._configure()
-    output.writer.filename = "output.vtk"
-    output.vertexInfoFields = ["vertex info"]
-    output.cellInfoFields = ["cell info"]
     
     dataProvider = TestProvider()
     output.preinitialize(dataProvider)
@@ -247,14 +241,14 @@
     """
     Test writeData().
     """
-    output = OutputManager()
+    output = MeshOutputManager()
+    output.inventory.writer.inventory.filename = "output.vtk"
+    output.inventory.writer.inventory.timeFormat = "%3.1f"
+    output.inventory.writer._configure()
+    output.inventory.vertexDataFields = ["vertex data 2",
+                                         "vertex data 1"]
+    output.inventory.cellDataFields = ["cell data"]
     output._configure()
-    output.writer._configure()
-    output.writer.filename = "output.vtk"
-    output.writer.timeFormat = "%3.1f"
-    output.vertexDataFields = ["vertex data 2",
-                               "vertex data 1"]
-    output.cellDataFields = ["cell data"]
     
     dataProvider = TestProvider()
     output.preinitialize(dataProvider)
@@ -273,16 +267,16 @@
     dataProvider = TestProvider()
 
     # Default values should be true
-    output = OutputManager()
+    output = MeshOutputManager()
+    output.inventory.writer._configure()
     output._configure()
-    output.writer._configure()
     output.preinitialize(dataProvider)
     output.initialize(self.normalizer)
     self.assertEqual(True, output._checkWrite(0.0))
     self.assertEqual(True, output._checkWrite(3.234e+8))
 
     # Check writing based on time
-    output = OutputManager()
+    output = MeshOutputManager()
     output._configure()
     output.writer._configure()
     output.preinitialize(dataProvider)
@@ -300,7 +294,7 @@
     self.assertEqual(True, output._checkWrite(t))
     
     # Check writing based on number of steps
-    output = OutputManager()
+    output = MeshOutputManager()
     output._configure()
     output.writer._configure()
     output.preinitialize(dataProvider)
@@ -90,31 +96,32 @@
   """
-  Unit testing of Python OutputManager object.
+  Unit testing of Python MeshOutputManager object.
   """
 

Modified: short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/testmeshio.py
===================================================================